@@ -269,6 +269,7 @@ class EditMetadataAction(InterfaceAction):
                 id_map = {}
 
         restrict_to_failed = restrict_to_failed or bool(args and args[0])
+        restrict_to_failed = restrict_to_failed and bool(failed_ids)
         if restrict_to_failed:
             db.data.set_marked_ids(failed_ids)
 
@@ -433,6 +434,7 @@ class EditMetadataAction(InterfaceAction):
         dest_id, src_ids = self.books_to_merge(rows)
         mi = self.gui.current_db.new_api.get_proxy_metadata(dest_id)
         title = mi.title
+        hpos = self.gui.library_view.horizontalScrollBar().value()
         if safe_merge:
             if not confirm_merge('<p>'+_(
                 'Book formats and metadata from the selected books '
@@ -450,7 +452,7 @@ class EditMetadataAction(InterfaceAction):
                 'into the <b>first selected book</b> (%s). '
                 'Metadata in the first selected book will not be changed. '
                 'Author, Title and all other metadata will <i>not</i> be merged.<br><br>'
-                'After merger the second and subsequently '
+                'After being merged, the second and subsequently '
                 'selected books, with any metadata they have will be <b>deleted</b>. <br><br>'
                 'All book formats of the first selected book will be kept '
                 'and any duplicate formats in the second and subsequently selected books '
@@ -464,7 +466,7 @@ class EditMetadataAction(InterfaceAction):
             if not confirm_merge('<p>'+_(
                 'Book formats and metadata from the selected books will be merged '
                 'into the <b>first selected book</b> (%s).<br><br>'
-                'After merger the second and '
+                'After being merged, the second and '
                 'subsequently selected books will be <b>deleted</b>. <br><br>'
                 'All book formats of the first selected book will be kept '
                 'and any duplicate formats in the second and subsequently selected books '
@@ -480,16 +482,16 @@ class EditMetadataAction(InterfaceAction):
             for row in rows:
                 if row.row() < rows[0].row():
                     dest_row -= 1
-            ci = self.gui.library_view.model().index(dest_row, 0)
-            if ci.isValid():
-                self.gui.library_view.setCurrentIndex(ci)
-                self.gui.library_view.model().current_changed(ci, ci)
+            self.gui.library_view.set_current_row(dest_row)
+        cr = self.gui.library_view.currentIndex().row()
+        self.gui.library_view.model().refresh_ids((dest_id,), cr)
+        self.gui.library_view.horizontalScrollBar().setValue(hpos)
 
     def add_formats(self, dest_id, src_books, replace=False):
         for src_book in src_books:
             if src_book:
                 fmt = os.path.splitext(src_book)[-1].replace('.', '').upper()
-                with open(src_book, 'rb') as f:
+                with lopen(src_book, 'rb') as f:
                     self.gui.library_view.model().db.add_format(dest_id, fmt, f, index_is_id=True,
                             notify=False, replace=replace)
 
